#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_HALFEPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_HALFEPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/halfeps.hpp>

#endif
